# Installation

The instructions below will help you to properly install the generated package to the lavalite project.

## Location

Extract the package contents to the folder 

`/packages/restaurant/reports/`

## Composer

Add the below entries in the `composer.json` file's autoload section and run the command `composer dump-autoload` in terminal.

```json

...
     "autoload": {
         ...

        "classmap": [
            ...
            
            "packages/restaurant/reports/database/seeds",
            
            ...
        ],
        "psr-4": {
            ...
            
            "Restaurant\\Reports\\": "packages/restaurant/reports/src",
            
            ...
        }
    },
...

```

## Config

Add the entries in service provider in `config/app.php`

```php

...
    'providers'       => [
        ...
        
        Restaurant\Reports\Providers\ReportsServiceProvider::class,
        
        ...
    ],

    ...

    'alias'             => [
        ...
        
        'Reports'  => Restaurant\Reports\Facades\Reports::class,
        
        ...
    ]
...

```

## Migrate

After service provider is set run the commapnd to migrate and seed the database.


    php artisan migrate
    php artisan db:seed --class=Restaurant\\ReportsTableSeeder

## Publishing


**Publishing configuration**

    php artisan vendor:publish --provider="Restaurant\Reports\Providers\ReportsServiceProvider" --tag="config"

**Publishing language**

    php artisan vendor:publish --provider="Restaurant\Reports\Providers\ReportsServiceProvider" --tag="lang"

**Publishing views**

    php artisan vendor:publish --provider="Restaurant\Reports\Providers\ReportsServiceProvider" --tag="view"


## URLs and APIs


### Web Urls

**Admin**

    http://path-to-route-folder/admin/reports/{modulename}

**User**

    http://path-to-route-folder/user/reports/{modulename}

**Public**

    http://path-to-route-folder/reports


### API endpoints

**List**
 
    http://path-to-route-folder/api/user/reports/{modulename}
    METHOD: GET

**Create**

    http://path-to-route-folder/api/user/reports/{modulename}
    METHOD: POST

**Edit**

    http://path-to-route-folder/api/user/reports/{modulename}/{id}
    METHOD: PUT

**Delete**

    http://path-to-route-folder/api/user/reports/{modulename}/{id}
    METHOD: DELETE

**Public List**

    http://path-to-route-folder/api/reports/{modulename}
    METHOD: GET

**Public Single**

    http://path-to-route-folder/api/reports/{modulename}/{slug}
    METHOD: GET