<?php

namespace Restaurant\Reports\Http\Controllers;

use App\Http\Controllers\PublicController as BaseController;
use Restaurant\Reports\Interfaces\ReportRepositoryInterface;

class ReportPublicController extends BaseController
{
    // use ReportWorkflow;

    /**
     * Constructor.
     *
     * @param type \Restaurant\Report\Interfaces\ReportRepositoryInterface $report
     *
     * @return type
     */
    public function __construct(ReportRepositoryInterface $report)
    {
        $this->repository = $report;
        parent::__construct();
    }

    /**
     * Show report's list.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function index()
    {
        $reports = $this->repository
        ->pushCriteria(app('Litepie\Repository\Criteria\RequestCriteria'))
        ->scopeQuery(function($query){
            return $query->orderBy('id','DESC');
        })->paginate();


        return $this->response->setMetaTitle(trans('reports::report.names'))
            ->view('reports::public.report.index')
            ->data(compact('reports'))
            ->output();
    }


    /**
     * Show report.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show($slug)
    {
        $report = $this->repository->scopeQuery(function($query) use ($slug) {
            return $query->orderBy('id','DESC')
                         ->where('slug', $slug);
        })->first(['*']);

        return $this->response->setMetaTitle($report->name . trans('reports::report.name'))
            ->view('reports::public.report.show')
            ->data(compact('report'))
            ->output();
    }

}
